Page 59 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 59

Home

    Seeing the end near, Robespierre fired a pistol at his
    head in an attempted suicide, but only succeeded in
    fracturing his jaw. For hours he lay on a green table, the
    same table where he and his followers had often sat

    planning the death of others. As he lay with his head on
    a wooden box, with blood flowing from his jaw, a
    workingman approached, looked into the shattered face
    and exclaimed, "There is a God!"

    At the guillotine the executioner tore away the
    bandage that was bound about his head causing the
    fractured jaw to fall, leaving a gaping chasm. The victim
    then emitted a tortured roar of agony that was heard to
    the farthermost extremities of the square. When his
    severed head was held up by the executioner, men and
    women fell into each others arms crying, "At last we are
    free! The tyrant is no more!" The Reign of Terror had

    a4

    ended.

    The end of the Reign of Terror was not the end of
    turmoil for France. Eighty years of war and revolution
    were to follow. The Directory (1795-1799) that
    succeeded the Convention lasted four years and was

    follow.

    that

    to

    were

    abolished because of its tyranny and corruption. The
    Consulate was formed (1799) and ended five years later.
    In 1804 Napoleon became emperor and a series of
    European wars followed resulting in France being
    invaded by Russians, Austrians, and Prussians. Napoleon
    was overthrown and France returned to a monarchy in
    1814 by calling Louis XVIII to the throne, only to be
    deposed by Napoleon six months later. Napoleon was

    54

    The Secret Side of History